# Ergate
Workflows made easy, your way.

> [!NOTE]
> There's plenty of more features that aren't yet documented. For example, Ergate supports dependency injection via `Depends(...)` in a similar way to FastAPI. Feel free to open a GitHub issue if you have any questions while we work on adding documentation to the project.


## Acknowledgements
- [Ziply Fiber](https://ziplyfiber.com): For giving me the initial idea to create this project and allowing me to turn it into a personal, open-source project.
- [FastAPI](https://github.com/tiangolo/fastapi): For inspiring me on the implementation of a bunch of the features supported by Ergate (such as the use of `Depends` for argument injection).
- [Sanic](https://github.com/sanic-org/sanic): For getting me originally into the open-source world and for their use of unique names in blueprints (similar to workflows in Ergate).
